@@ -198,8 +198,8 @@ class OpenAPI(object):
         return result.json()
 
     @classmethod
-    def generate(cls, root_urlconf, servers=None):
+    def generate(cls, root_urlconf, servers=None, version="0.0.1", title='Openapi Documentation'):
         root_urlconf = __import__(root_urlconf)
-        openapi = cls(servers=servers)
+        openapi = cls(servers=servers, version=version, title=title)
         openapi.routes = collect_routes(all_resolver=root_urlconf.urls.urlpatterns)
         return openapi
